=========
Reference
=========

.. toctree::

   covid

   preprocessing

PIT
-----

.. automodule:: sisu.pit.gismo_wrapper
    :members:

.. automodule:: sisu.pit.embedding_idf
    :members:

.. automodule:: sisu.pit.building_summary
    :members:
